"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .finetuneablemodel import FineTuneableModel
from .githubrepositoryin import GithubRepositoryIn, GithubRepositoryInTypedDict
from .trainingfile import TrainingFile, TrainingFileTypedDict
from .trainingparametersin import TrainingParametersIn, TrainingParametersInTypedDict
from .wandbintegration import WandbIntegration, WandbIntegrationTypedDict
from mistralai.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


JobInIntegrationsTypedDict = WandbIntegrationTypedDict


JobInIntegrations = WandbIntegration


JobInRepositoriesTypedDict = GithubRepositoryInTypedDict


JobInRepositories = GithubRepositoryIn


class JobInTypedDict(TypedDict):
    model: FineTuneableModel
    r"""The name of the model to fine-tune."""
    hyperparameters: TrainingParametersInTypedDict
    r"""The fine-tuning hyperparameter settings used in a fine-tune job."""
    training_files: NotRequired[List[TrainingFileTypedDict]]
    validation_files: NotRequired[Nullable[List[str]]]
    r"""A list containing the IDs of uploaded files that contain validation data. If you provide these files, the data is used to generate validation metrics periodically during fine-tuning. These metrics can be viewed in `checkpoints` when getting the status of a running fine-tuning job. The same data should not be present in both train and validation files."""
    suffix: NotRequired[Nullable[str]]
    r"""A string that will be added to your fine-tuning model name. For example, a suffix of \"my-great-model\" would produce a model name like `ft:open-mistral-7b:my-great-model:xxx...`"""
    integrations: NotRequired[Nullable[List[JobInIntegrationsTypedDict]]]
    r"""A list of integrations to enable for your fine-tuning job."""
    repositories: NotRequired[List[JobInRepositoriesTypedDict]]
    auto_start: NotRequired[bool]
    r"""This field will be required in a future release."""


class JobIn(BaseModel):
    model: FineTuneableModel
    r"""The name of the model to fine-tune."""

    hyperparameters: TrainingParametersIn
    r"""The fine-tuning hyperparameter settings used in a fine-tune job."""

    training_files: Optional[List[TrainingFile]] = None

    validation_files: OptionalNullable[List[str]] = UNSET
    r"""A list containing the IDs of uploaded files that contain validation data. If you provide these files, the data is used to generate validation metrics periodically during fine-tuning. These metrics can be viewed in `checkpoints` when getting the status of a running fine-tuning job. The same data should not be present in both train and validation files."""

    suffix: OptionalNullable[str] = UNSET
    r"""A string that will be added to your fine-tuning model name. For example, a suffix of \"my-great-model\" would produce a model name like `ft:open-mistral-7b:my-great-model:xxx...`"""

    integrations: OptionalNullable[List[JobInIntegrations]] = UNSET
    r"""A list of integrations to enable for your fine-tuning job."""

    repositories: Optional[List[JobInRepositories]] = None

    auto_start: Optional[bool] = None
    r"""This field will be required in a future release."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "training_files",
            "validation_files",
            "suffix",
            "integrations",
            "repositories",
            "auto_start",
        ]
        nullable_fields = ["validation_files", "suffix", "integrations"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import json
from typing import Optional, Union

import google.auth
import google.auth.credentials
import google.auth.transport
import google.auth.transport.requests
import httpx
from mistralai_gcp import models
from mistralai_gcp._hooks import BeforeRequestHook, SDKHooks
from mistralai_gcp.chat import Chat
from mistralai_gcp.fim import Fim
from mistralai_gcp.types import Nullable

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, HttpClient
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, NoOpLogger
from .utils.retries import RetryConfig


class MistralGoogleCloud(BaseSDK):
    r"""Mistral AI API: Our Chat Completion and Embeddings APIs specification. Create your account on [La Plateforme](https://console.mistral.ai) to get access and read the [docs](https://docs.mistral.ai) to learn how to use it."""

    chat: Chat
    fim: Fim
    r"""Chat Completion API"""

    def __init__(
        self,
        region: str = "europe-west4",
        project_id: Optional[str] = None,
        access_token: Optional[str] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: Optional[Nullable[RetryConfig]] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param region: The Google Cloud region to use for all methods
        :param project_id: The project ID to use for all methods
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        """

        if not access_token:
            credentials, loaded_project_id = google.auth.default(
                scopes=["https://www.googleapis.com/auth/cloud-platform"],
            )
            credentials.refresh(google.auth.transport.requests.Request())

            if not isinstance(credentials, google.auth.credentials.Credentials):
                raise models.SDKError(
                    "credentials must be an instance of google.auth.credentials.Credentials"
                )

            project_id = project_id or loaded_project_id
        if project_id is None:
            raise models.SDKError("project_id must be provided")

        def auth_token() -> str:
            if access_token:
                return access_token
            credentials.refresh(google.auth.transport.requests.Request())
            token = credentials.token
            if not token:
                raise models.SDKError("Failed to get token from credentials")
            return token

        if client is None:
            client = httpx.Client()

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        if async_client is None:
            async_client = httpx.AsyncClient()

        if debug_logger is None:
            debug_logger = NoOpLogger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        security = None
        if callable(auth_token):
            security = lambda: models.Security(  # pylint: disable=unnecessary-lambda-assignment
                api_key=auth_token()
            )
        else:
            security = models.Security(api_key=auth_token)

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                async_client=async_client,
                security=security,
                server_url=f"https://{region}-aiplatform.googleapis.com",
                server=None,
                retry_config=retry_config,
                debug_logger=debug_logger,
            ),
        )

        hooks = SDKHooks()

        hook = GoogleCloudBeforeRequestHook(region, project_id)
        hooks.register_before_request_hook(hook)

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, self.sdk_configuration.client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        self._init_sdks()

    def _init_sdks(self):
        self.chat = Chat(self.sdk_configuration)
        self.fim = Fim(self.sdk_configuration)


class GoogleCloudBeforeRequestHook(BeforeRequestHook):

    def __init__(self, region: str, project_id: str):
        self.region = region
        self.project_id = project_id

    def before_request(
        self, hook_ctx, request: httpx.Request
    ) -> Union[httpx.Request, Exception]:
        # The goal of this function is to template in the region, project, model, and model_version into the URL path
        # We do this here so that the API remains more user-friendly
        model = None
        model_version = None
        new_content = None
        if request.content:
            parsed = json.loads(request.content.decode("utf-8"))
            model_raw = parsed.get("model")
            model = "-".join(model_raw.split("-")[:-1])
            model_version = model_raw.split("-")[-1]
            parsed["model"] = model
            new_content = json.dumps(parsed).encode("utf-8")

        if model == "":
            raise models.SDKError("model must be provided")

        if model_version is None:
            raise models.SDKError("model_version must be provided")

        stream = "streamRawPredict" in request.url.path
        specifier = "streamRawPredict" if stream else "rawPredict"
        url = f"/v1/projects/{self.project_id}/locations/{self.region}/publishers/mistralai/models/{model}@{model_version}:{specifier}"

        headers = dict(request.headers)
        # Delete content-length header as it will need to be recalculated
        headers.pop("content-length", None)

        next_request = httpx.Request(
            method=request.method,
            url=request.url.copy_with(path=url),
            headers=headers,
            content=new_content,
            stream=None,
        )

        return next_request



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assistantmessage import AssistantMessage, AssistantMessageTypedDict
from .responseformat import ResponseFormat, ResponseFormatTypedDict
from .systemmessage import SystemMessage, SystemMessageTypedDict
from .tool import Tool, ToolTypedDict
from .toolchoice import ToolChoice, ToolChoiceTypedDict
from .toolchoiceenum import ToolChoiceEnum
from .toolmessage import ToolMessage, ToolMessageTypedDict
from .usermessage import UserMessage, UserMessageTypedDict
from mistralai_gcp.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai_gcp.utils import get_discriminator
from pydantic import Discriminator, Tag, model_serializer
from typing import List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


StopTypedDict = Union[str, List[str]]
r"""Stop generation if this token is detected. Or if one of these tokens is detected when providing an array"""


Stop = Union[str, List[str]]
r"""Stop generation if this token is detected. Or if one of these tokens is detected when providing an array"""


MessagesTypedDict = Union[
    SystemMessageTypedDict,
    UserMessageTypedDict,
    AssistantMessageTypedDict,
    ToolMessageTypedDict,
]


Messages = Annotated[
    Union[
        Annotated[AssistantMessage, Tag("assistant")],
        Annotated[SystemMessage, Tag("system")],
        Annotated[ToolMessage, Tag("tool")],
        Annotated[UserMessage, Tag("user")],
    ],
    Discriminator(lambda m: get_discriminator(m, "role", "role")),
]


ChatCompletionStreamRequestToolChoiceTypedDict = Union[
    ToolChoiceTypedDict, ToolChoiceEnum
]


ChatCompletionStreamRequestToolChoice = Union[ToolChoice, ToolChoiceEnum]


class ChatCompletionStreamRequestTypedDict(TypedDict):
    model: Nullable[str]
    r"""ID of the model to use. You can use the [List Available Models](/api/#tag/models/operation/list_models_v1_models_get) API to see all of your available models, or see our [Model overview](/models) for model descriptions."""
    messages: List[MessagesTypedDict]
    r"""The prompt(s) to generate completions for, encoded as a list of dict with role and content."""
    temperature: NotRequired[Nullable[float]]
    r"""What sampling temperature to use, we recommend between 0.0 and 0.7. Higher values like 0.7 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. We generally recommend altering this or `top_p` but not both. The default value varies depending on the model you are targeting. Call the `/models` endpoint to retrieve the appropriate value."""
    top_p: NotRequired[float]
    r"""Nucleus sampling, where the model considers the results of the tokens with `top_p` probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered. We generally recommend altering this or `temperature` but not both."""
    max_tokens: NotRequired[Nullable[int]]
    r"""The maximum number of tokens to generate in the completion. The token count of your prompt plus `max_tokens` cannot exceed the model's context length."""
    stream: NotRequired[bool]
    stop: NotRequired[StopTypedDict]
    r"""Stop generation if this token is detected. Or if one of these tokens is detected when providing an array"""
    random_seed: NotRequired[Nullable[int]]
    r"""The seed to use for random sampling. If set, different calls will generate deterministic results."""
    response_format: NotRequired[ResponseFormatTypedDict]
    tools: NotRequired[Nullable[List[ToolTypedDict]]]
    tool_choice: NotRequired[ChatCompletionStreamRequestToolChoiceTypedDict]
    presence_penalty: NotRequired[float]
    r"""presence_penalty determines how much the model penalizes the repetition of words or phrases. A higher presence penalty encourages the model to use a wider variety of words and phrases, making the output more diverse and creative."""
    frequency_penalty: NotRequired[float]
    r"""frequency_penalty penalizes the repetition of words based on their frequency in the generated text. A higher frequency penalty discourages the model from repeating words that have already appeared frequently in the output, promoting diversity and reducing repetition."""
    n: NotRequired[Nullable[int]]
    r"""Number of completions to return for each request, input tokens are only billed once."""


class ChatCompletionStreamRequest(BaseModel):
    model: Nullable[str]
    r"""ID of the model to use. You can use the [List Available Models](/api/#tag/models/operation/list_models_v1_models_get) API to see all of your available models, or see our [Model overview](/models) for model descriptions."""

    messages: List[Messages]
    r"""The prompt(s) to generate completions for, encoded as a list of dict with role and content."""

    temperature: OptionalNullable[float] = UNSET
    r"""What sampling temperature to use, we recommend between 0.0 and 0.7. Higher values like 0.7 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. We generally recommend altering this or `top_p` but not both. The default value varies depending on the model you are targeting. Call the `/models` endpoint to retrieve the appropriate value."""

    top_p: Optional[float] = 1
    r"""Nucleus sampling, where the model considers the results of the tokens with `top_p` probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered. We generally recommend altering this or `temperature` but not both."""

    max_tokens: OptionalNullable[int] = UNSET
    r"""The maximum number of tokens to generate in the completion. The token count of your prompt plus `max_tokens` cannot exceed the model's context length."""

    stream: Optional[bool] = True

    stop: Optional[Stop] = None
    r"""Stop generation if this token is detected. Or if one of these tokens is detected when providing an array"""

    random_seed: OptionalNullable[int] = UNSET
    r"""The seed to use for random sampling. If set, different calls will generate deterministic results."""

    response_format: Optional[ResponseFormat] = None

    tools: OptionalNullable[List[Tool]] = UNSET

    tool_choice: Optional[ChatCompletionStreamRequestToolChoice] = None

    presence_penalty: Optional[float] = 0
    r"""presence_penalty determines how much the model penalizes the repetition of words or phrases. A higher presence penalty encourages the model to use a wider variety of words and phrases, making the output more diverse and creative."""

    frequency_penalty: Optional[float] = 0
    r"""frequency_penalty penalizes the repetition of words based on their frequency in the generated text. A higher frequency penalty discourages the model from repeating words that have already appeared frequently in the output, promoting diversity and reducing repetition."""

    n: OptionalNullable[int] = UNSET
    r"""Number of completions to return for each request, input tokens are only billed once."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "temperature",
            "top_p",
            "max_tokens",
            "stream",
            "stop",
            "random_seed",
            "response_format",
            "tools",
            "tool_choice",
            "presence_penalty",
            "frequency_penalty",
            "n",
        ]
        nullable_fields = [
            "model",
            "temperature",
            "max_tokens",
            "random_seed",
            "tools",
            "n",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


ResponseFormats = Literal["text", "json_object"]
r"""An object specifying the format that the model must output. Setting to `{ \"type\": \"json_object\" }` enables JSON mode, which guarantees the message the model generates is in JSON. When using JSON mode you MUST also instruct the model to produce JSON yourself with a system or a user message."""



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from typing import Any, Callable, Dict, Optional, Union

import httpx
from mistralai_azure import models, utils
from mistralai_azure._hooks import SDKHooks
from mistralai_azure.chat import Chat
from mistralai_azure.types import Nullable

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, HttpClient
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, NoOpLogger
from .utils.retries import RetryConfig


class MistralAzure(BaseSDK):
    r"""Mistral AI API: Our Chat Completion and Embeddings APIs specification. Create your account on [La Plateforme](https://console.mistral.ai) to get access and read the [docs](https://docs.mistral.ai) to learn how to use it."""

    chat: Chat
    r"""Chat Completion API"""

    def __init__(
        self,
        azure_api_key: Union[str, Callable[[], str]],
        azure_endpoint: str,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: Optional[Nullable[RetryConfig]] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param azure_api_key: The azure_api_key required for authentication
        :param azure_endpoint: The Azure AI endpoint URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        """
        # if azure_endpoint doesn't end with `/v1` add it
        if not azure_endpoint.endswith("/"):
            azure_endpoint += "/"
        if not azure_endpoint.endswith("v1/"):
            azure_endpoint += "v1/"
        server_url = azure_endpoint

        if client is None:
            client = httpx.Client()

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        if async_client is None:
            async_client = httpx.AsyncClient()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        if debug_logger is None:
            debug_logger = NoOpLogger()

        security: Any = None
        if callable(azure_api_key):
            security = lambda: models.Security(  # pylint: disable=unnecessary-lambda-assignment
                api_key=azure_api_key()
            )
        else:
            security = models.Security(api_key=azure_api_key)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                async_client=async_client,
                security=security,
                server_url=server_url,
                server=None,
                retry_config=retry_config,
                debug_logger=debug_logger,
            ),
        )

        hooks = SDKHooks()

        current_server_url, *_ = self.sdk_configuration.get_server_details()
        server_url, self.sdk_configuration.client = hooks.sdk_init(
            current_server_url, self.sdk_configuration.client
        )
        if current_server_url != server_url:
            self.sdk_configuration.server_url = server_url

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        self._init_sdks()

    def _init_sdks(self):
        self.chat = Chat(self.sdk_configuration)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .agentscompletionrequest import (
    AgentsCompletionRequest,
    AgentsCompletionRequestMessages,
    AgentsCompletionRequestMessagesTypedDict,
    AgentsCompletionRequestStop,
    AgentsCompletionRequestStopTypedDict,
    AgentsCompletionRequestToolChoice,
    AgentsCompletionRequestToolChoiceTypedDict,
    AgentsCompletionRequestTypedDict,
)
from .agentscompletionstreamrequest import (
    AgentsCompletionStreamRequest,
    AgentsCompletionStreamRequestMessages,
    AgentsCompletionStreamRequestMessagesTypedDict,
    AgentsCompletionStreamRequestStop,
    AgentsCompletionStreamRequestStopTypedDict,
    AgentsCompletionStreamRequestToolChoice,
    AgentsCompletionStreamRequestToolChoiceTypedDict,
    AgentsCompletionStreamRequestTypedDict,
)
from .apiendpoint import APIEndpoint
from .archiveftmodelout import (
    ArchiveFTModelOut,
    ArchiveFTModelOutObject,
    ArchiveFTModelOutTypedDict,
)
from .assistantmessage import (
    AssistantMessage,
    AssistantMessageContent,
    AssistantMessageContentTypedDict,
    AssistantMessageRole,
    AssistantMessageTypedDict,
)
from .basemodelcard import BaseModelCard, BaseModelCardTypedDict, Type
from .batcherror import BatchError, BatchErrorTypedDict
from .batchjobin import BatchJobIn, BatchJobInTypedDict
from .batchjobout import BatchJobOut, BatchJobOutObject, BatchJobOutTypedDict
from .batchjobsout import BatchJobsOut, BatchJobsOutObject, BatchJobsOutTypedDict
from .batchjobstatus import BatchJobStatus
from .chatclassificationrequest import (
    ChatClassificationRequest,
    ChatClassificationRequestInputs,
    ChatClassificationRequestInputsTypedDict,
    ChatClassificationRequestTypedDict,
    One,
    OneTypedDict,
    Two,
    TwoTypedDict,
)
from .chatcompletionchoice import (
    ChatCompletionChoice,
    ChatCompletionChoiceTypedDict,
    FinishReason,
)
from .chatcompletionrequest import (
    ChatCompletionRequest,
    ChatCompletionRequestToolChoice,
    ChatCompletionRequestToolChoiceTypedDict,
    ChatCompletionRequestTypedDict,
    Messages,
    MessagesTypedDict,
    Stop,
    StopTypedDict,
)
from .chatcompletionresponse import (
    ChatCompletionResponse,
    ChatCompletionResponseTypedDict,
)
from .chatcompletionstreamrequest import (
    ChatCompletionStreamRequest,
    ChatCompletionStreamRequestMessages,
    ChatCompletionStreamRequestMessagesTypedDict,
    ChatCompletionStreamRequestStop,
    ChatCompletionStreamRequestStopTypedDict,
    ChatCompletionStreamRequestToolChoice,
    ChatCompletionStreamRequestToolChoiceTypedDict,
    ChatCompletionStreamRequestTypedDict,
)
from .checkpointout import CheckpointOut, CheckpointOutTypedDict
from .classificationobject import ClassificationObject, ClassificationObjectTypedDict
from .classificationrequest import (
    ClassificationRequest,
    ClassificationRequestInputs,
    ClassificationRequestInputsTypedDict,
    ClassificationRequestTypedDict,
)
from .classificationresponse import (
    ClassificationResponse,
    ClassificationResponseTypedDict,
)
from .completionchunk import CompletionChunk, CompletionChunkTypedDict
from .completionevent import CompletionEvent, CompletionEventTypedDict
from .completionresponsestreamchoice import (
    CompletionResponseStreamChoice,
    CompletionResponseStreamChoiceFinishReason,
    CompletionResponseStreamChoiceTypedDict,
)
from .contentchunk import ContentChunk, ContentChunkTypedDict
from .delete_model_v1_models_model_id_deleteop import (
    DeleteModelV1ModelsModelIDDeleteRequest,
    DeleteModelV1ModelsModelIDDeleteRequestTypedDict,
)
from .deletefileout import DeleteFileOut, DeleteFileOutTypedDict
from .deletemodelout import DeleteModelOut, DeleteModelOutTypedDict
from .deltamessage import Content, ContentTypedDict, DeltaMessage, DeltaMessageTypedDict
from .detailedjobout import (
    DetailedJobOut,
    DetailedJobOutIntegrations,
    DetailedJobOutIntegrationsTypedDict,
    DetailedJobOutObject,
    DetailedJobOutRepositories,
    DetailedJobOutRepositoriesTypedDict,
    DetailedJobOutStatus,
    DetailedJobOutTypedDict,
)
from .embeddingrequest import (
    EmbeddingRequest,
    EmbeddingRequestTypedDict,
    Inputs,
    InputsTypedDict,
)
from .embeddingresponse import EmbeddingResponse, EmbeddingResponseTypedDict
from .embeddingresponsedata import EmbeddingResponseData, EmbeddingResponseDataTypedDict
from .eventout import EventOut, EventOutTypedDict
from .filepurpose import FilePurpose
from .files_api_routes_delete_fileop import (
    FilesAPIRoutesDeleteFileRequest,
    FilesAPIRoutesDeleteFileRequestTypedDict,
)
from .files_api_routes_download_fileop import (
    FilesAPIRoutesDownloadFileRequest,
    FilesAPIRoutesDownloadFileRequestTypedDict,
)
from .files_api_routes_list_filesop import (
    FilesAPIRoutesListFilesRequest,
    FilesAPIRoutesListFilesRequestTypedDict,
)
from .files_api_routes_retrieve_fileop import (
    FilesAPIRoutesRetrieveFileRequest,
    FilesAPIRoutesRetrieveFileRequestTypedDict,
)
from .files_api_routes_upload_fileop import (
    File,
    FileTypedDict,
    FilesAPIRoutesUploadFileMultiPartBodyParams,
    FilesAPIRoutesUploadFileMultiPartBodyParamsTypedDict,
)
from .fileschema import FileSchema, FileSchemaTypedDict
from .fimcompletionrequest import (
    FIMCompletionRequest,
    FIMCompletionRequestStop,
    FIMCompletionRequestStopTypedDict,
    FIMCompletionRequestTypedDict,
)
from .fimcompletionresponse import FIMCompletionResponse, FIMCompletionResponseTypedDict
from .fimcompletionstreamrequest import (
    FIMCompletionStreamRequest,
    FIMCompletionStreamRequestStop,
    FIMCompletionStreamRequestStopTypedDict,
    FIMCompletionStreamRequestTypedDict,
)
from .finetuneablemodel import FineTuneableModel
from .ftmodelcapabilitiesout import (
    FTModelCapabilitiesOut,
    FTModelCapabilitiesOutTypedDict,
)
from .ftmodelcard import FTModelCard, FTModelCardType, FTModelCardTypedDict
from .ftmodelout import FTModelOut, FTModelOutObject, FTModelOutTypedDict
from .function import Function, FunctionTypedDict
from .functioncall import (
    Arguments,
    ArgumentsTypedDict,
    FunctionCall,
    FunctionCallTypedDict,
)
from .functionname import FunctionName, FunctionNameTypedDict
from .githubrepositoryin import (
    GithubRepositoryIn,
    GithubRepositoryInType,
    GithubRepositoryInTypedDict,
)
from .githubrepositoryout import (
    GithubRepositoryOut,
    GithubRepositoryOutType,
    GithubRepositoryOutTypedDict,
)
from .httpvalidationerror import HTTPValidationError, HTTPValidationErrorData
from .imageurl import ImageURL, ImageURLTypedDict
from .imageurlchunk import (
    ImageURLChunk,
    ImageURLChunkImageURL,
    ImageURLChunkImageURLTypedDict,
    ImageURLChunkType,
    ImageURLChunkTypedDict,
)
from .jobin import (
    JobIn,
    JobInIntegrations,
    JobInIntegrationsTypedDict,
    JobInRepositories,
    JobInRepositoriesTypedDict,
    JobInTypedDict,
)
from .jobmetadataout import JobMetadataOut, JobMetadataOutTypedDict
from .jobout import (
    Integrations,
    IntegrationsTypedDict,
    JobOut,
    JobOutTypedDict,
    Object,
    Repositories,
    RepositoriesTypedDict,
    Status,
)
from .jobs_api_routes_batch_cancel_batch_jobop import (
    JobsAPIRoutesBatchCancelBatchJobRequest,
    JobsAPIRoutesBatchCancelBatchJobRequestTypedDict,
)
from .jobs_api_routes_batch_get_batch_jobop import (
    JobsAPIRoutesBatchGetBatchJobRequest,
    JobsAPIRoutesBatchGetBatchJobRequestTypedDict,
)
from .jobs_api_routes_batch_get_batch_jobsop import (
    JobsAPIRoutesBatchGetBatchJobsRequest,
    JobsAPIRoutesBatchGetBatchJobsRequestTypedDict,
)
from .jobs_api_routes_fine_tuning_archive_fine_tuned_modelop import (
    JobsAPIRoutesFineTuningArchiveFineTunedModelRequest,
    JobsAPIRoutesFineTuningArchiveFineTunedModelRequestTypedDict,
)
from .jobs_api_routes_fine_tuning_cancel_fine_tuning_jobop import (
    JobsAPIRoutesFineTuningCancelFineTuningJobRequest,
    JobsAPIRoutesFineTuningCancelFineTuningJobRequestTypedDict,
)
from .jobs_api_routes_fine_tuning_create_fine_tuning_jobop import (
    JobsAPIRoutesFineTuningCreateFineTuningJobResponse,
    JobsAPIRoutesFineTuningCreateFineTuningJobResponseTypedDict,
)
from .jobs_api_routes_fine_tuning_get_fine_tuning_jobop import (
    JobsAPIRoutesFineTuningGetFineTuningJobRequest,
    JobsAPIRoutesFineTuningGetFineTuningJobRequestTypedDict,
)
from .jobs_api_routes_fine_tuning_get_fine_tuning_jobsop import (
    JobsAPIRoutesFineTuningGetFineTuningJobsRequest,
    JobsAPIRoutesFineTuningGetFineTuningJobsRequestTypedDict,
    QueryParamStatus,
)
from .jobs_api_routes_fine_tuning_start_fine_tuning_jobop import (
    JobsAPIRoutesFineTuningStartFineTuningJobRequest,
    JobsAPIRoutesFineTuningStartFineTuningJobRequestTypedDict,
)
from .jobs_api_routes_fine_tuning_unarchive_fine_tuned_modelop import (
    JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequest,
    JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequestTypedDict,
)
from .jobs_api_routes_fine_tuning_update_fine_tuned_modelop import (
    JobsAPIRoutesFineTuningUpdateFineTunedModelRequest,
    JobsAPIRoutesFineTuningUpdateFineTunedModelRequestTypedDict,
)
from .jobsout import JobsOut, JobsOutObject, JobsOutTypedDict
from .legacyjobmetadataout import (
    LegacyJobMetadataOut,
    LegacyJobMetadataOutObject,
    LegacyJobMetadataOutTypedDict,
)
from .listfilesout import ListFilesOut, ListFilesOutTypedDict
from .metricout import MetricOut, MetricOutTypedDict
from .modelcapabilities import ModelCapabilities, ModelCapabilitiesTypedDict
from .modellist import Data, DataTypedDict, ModelList, ModelListTypedDict
from .responseformat import ResponseFormat, ResponseFormatTypedDict
from .responseformats import ResponseFormats
from .retrieve_model_v1_models_model_id_getop import (
    RetrieveModelV1ModelsModelIDGetRequest,
    RetrieveModelV1ModelsModelIDGetRequestTypedDict,
    RetrieveModelV1ModelsModelIDGetResponseRetrieveModelV1ModelsModelIDGet,
    RetrieveModelV1ModelsModelIDGetResponseRetrieveModelV1ModelsModelIDGetTypedDict,
)
from .retrievefileout import RetrieveFileOut, RetrieveFileOutTypedDict
from .sampletype import SampleType
from .sdkerror import SDKError
from .security import Security, SecurityTypedDict
from .source import Source
from .systemmessage import (
    Role,
    SystemMessage,
    SystemMessageContent,
    SystemMessageContentTypedDict,
    SystemMessageTypedDict,
)
from .textchunk import TextChunk, TextChunkType, TextChunkTypedDict
from .tool import Tool, ToolTypedDict
from .toolcall import ToolCall, ToolCallTypedDict
from .toolchoice import ToolChoice, ToolChoiceTypedDict
from .toolchoiceenum import ToolChoiceEnum
from .toolmessage import ToolMessage, ToolMessageRole, ToolMessageTypedDict
from .tooltypes import ToolTypes
from .trainingfile import TrainingFile, TrainingFileTypedDict
from .trainingparameters import TrainingParameters, TrainingParametersTypedDict
from .trainingparametersin import TrainingParametersIn, TrainingParametersInTypedDict
from .unarchiveftmodelout import (
    UnarchiveFTModelOut,
    UnarchiveFTModelOutObject,
    UnarchiveFTModelOutTypedDict,
)
from .updateftmodelin import UpdateFTModelIn, UpdateFTModelInTypedDict
from .uploadfileout import UploadFileOut, UploadFileOutTypedDict
from .usageinfo import UsageInfo, UsageInfoTypedDict
from .usermessage import (
    UserMessage,
    UserMessageContent,
    UserMessageContentTypedDict,
    UserMessageRole,
    UserMessageTypedDict,
)
from .validationerror import (
    Loc,
    LocTypedDict,
    ValidationError,
    ValidationErrorTypedDict,
)
from .wandbintegration import (
    WandbIntegration,
    WandbIntegrationType,
    WandbIntegrationTypedDict,
)
from .wandbintegrationout import (
    WandbIntegrationOut,
    WandbIntegrationOutType,
    WandbIntegrationOutTypedDict,
)

__all__ = [
    "APIEndpoint",
    "AgentsCompletionRequest",
    "AgentsCompletionRequestMessages",
    "AgentsCompletionRequestMessagesTypedDict",
    "AgentsCompletionRequestStop",
    "AgentsCompletionRequestStopTypedDict",
    "AgentsCompletionRequestToolChoice",
    "AgentsCompletionRequestToolChoiceTypedDict",
    "AgentsCompletionRequestTypedDict",
    "AgentsCompletionStreamRequest",
    "AgentsCompletionStreamRequestMessages",
    "AgentsCompletionStreamRequestMessagesTypedDict",
    "AgentsCompletionStreamRequestStop",
    "AgentsCompletionStreamRequestStopTypedDict",
    "AgentsCompletionStreamRequestToolChoice",
    "AgentsCompletionStreamRequestToolChoiceTypedDict",
    "AgentsCompletionStreamRequestTypedDict",
    "ArchiveFTModelOut",
    "ArchiveFTModelOutObject",
    "ArchiveFTModelOutTypedDict",
    "Arguments",
    "ArgumentsTypedDict",
    "AssistantMessage",
    "AssistantMessageContent",
    "AssistantMessageContentTypedDict",
    "AssistantMessageRole",
    "AssistantMessageTypedDict",
    "BaseModelCard",
    "BaseModelCardTypedDict",
    "BatchError",
    "BatchErrorTypedDict",
    "BatchJobIn",
    "BatchJobInTypedDict",
    "BatchJobOut",
    "BatchJobOutObject",
    "BatchJobOutTypedDict",
    "BatchJobStatus",
    "BatchJobsOut",
    "BatchJobsOutObject",
    "BatchJobsOutTypedDict",
    "ChatClassificationRequest",
    "ChatClassificationRequestInputs",
    "ChatClassificationRequestInputsTypedDict",
    "ChatClassificationRequestTypedDict",
    "ChatCompletionChoice",
    "ChatCompletionChoiceTypedDict",
    "ChatCompletionRequest",
    "ChatCompletionRequestToolChoice",
    "ChatCompletionRequestToolChoiceTypedDict",
    "ChatCompletionRequestTypedDict",
    "ChatCompletionResponse",
    "ChatCompletionResponseTypedDict",
    "ChatCompletionStreamRequest",
    "ChatCompletionStreamRequestMessages",
    "ChatCompletionStreamRequestMessagesTypedDict",
    "ChatCompletionStreamRequestStop",
    "ChatCompletionStreamRequestStopTypedDict",
    "ChatCompletionStreamRequestToolChoice",
    "ChatCompletionStreamRequestToolChoiceTypedDict",
    "ChatCompletionStreamRequestTypedDict",
    "CheckpointOut",
    "CheckpointOutTypedDict",
    "ClassificationObject",
    "ClassificationObjectTypedDict",
    "ClassificationRequest",
    "ClassificationRequestInputs",
    "ClassificationRequestInputsTypedDict",
    "ClassificationRequestTypedDict",
    "ClassificationResponse",
    "ClassificationResponseTypedDict",
    "CompletionChunk",
    "CompletionChunkTypedDict",
    "CompletionEvent",
    "CompletionEventTypedDict",
    "CompletionResponseStreamChoice",
    "CompletionResponseStreamChoiceFinishReason",
    "CompletionResponseStreamChoiceTypedDict",
    "Content",
    "ContentChunk",
    "ContentChunkTypedDict",
    "ContentTypedDict",
    "Data",
    "DataTypedDict",
    "DeleteFileOut",
    "DeleteFileOutTypedDict",
    "DeleteModelOut",
    "DeleteModelOutTypedDict",
    "DeleteModelV1ModelsModelIDDeleteRequest",
    "DeleteModelV1ModelsModelIDDeleteRequestTypedDict",
    "DeltaMessage",
    "DeltaMessageTypedDict",
    "DetailedJobOut",
    "DetailedJobOutIntegrations",
    "DetailedJobOutIntegrationsTypedDict",
    "DetailedJobOutObject",
    "DetailedJobOutRepositories",
    "DetailedJobOutRepositoriesTypedDict",
    "DetailedJobOutStatus",
    "DetailedJobOutTypedDict",
    "EmbeddingRequest",
    "EmbeddingRequestTypedDict",
    "EmbeddingResponse",
    "EmbeddingResponseData",
    "EmbeddingResponseDataTypedDict",
    "EmbeddingResponseTypedDict",
    "EventOut",
    "EventOutTypedDict",
    "FIMCompletionRequest",
    "FIMCompletionRequestStop",
    "FIMCompletionRequestStopTypedDict",
    "FIMCompletionRequestTypedDict",
    "FIMCompletionResponse",
    "FIMCompletionResponseTypedDict",
    "FIMCompletionStreamRequest",
    "FIMCompletionStreamRequestStop",
    "FIMCompletionStreamRequestStopTypedDict",
    "FIMCompletionStreamRequestTypedDict",
    "FTModelCapabilitiesOut",
    "FTModelCapabilitiesOutTypedDict",
    "FTModelCard",
    "FTModelCardType",
    "FTModelCardTypedDict",
    "FTModelOut",
    "FTModelOutObject",
    "FTModelOutTypedDict",
    "File",
    "FilePurpose",
    "FileSchema",
    "FileSchemaTypedDict",
    "FileTypedDict",
    "FilesAPIRoutesDeleteFileRequest",
    "FilesAPIRoutesDeleteFileRequestTypedDict",
    "FilesAPIRoutesDownloadFileRequest",
    "FilesAPIRoutesDownloadFileRequestTypedDict",
    "FilesAPIRoutesListFilesRequest",
    "FilesAPIRoutesListFilesRequestTypedDict",
    "FilesAPIRoutesRetrieveFileRequest",
    "FilesAPIRoutesRetrieveFileRequestTypedDict",
    "FilesAPIRoutesUploadFileMultiPartBodyParams",
    "FilesAPIRoutesUploadFileMultiPartBodyParamsTypedDict",
    "FineTuneableModel",
    "FinishReason",
    "Function",
    "FunctionCall",
    "FunctionCallTypedDict",
    "FunctionName",
    "FunctionNameTypedDict",
    "FunctionTypedDict",
    "GithubRepositoryIn",
    "GithubRepositoryInType",
    "GithubRepositoryInTypedDict",
    "GithubRepositoryOut",
    "GithubRepositoryOutType",
    "GithubRepositoryOutTypedDict",
    "HTTPValidationError",
    "HTTPValidationErrorData",
    "ImageURL",
    "ImageURLChunk",
    "ImageURLChunkImageURL",
    "ImageURLChunkImageURLTypedDict",
    "ImageURLChunkType",
    "ImageURLChunkTypedDict",
    "ImageURLTypedDict",
    "Inputs",
    "InputsTypedDict",
    "Integrations",
    "IntegrationsTypedDict",
    "JobIn",
    "JobInIntegrations",
    "JobInIntegrationsTypedDict",
    "JobInRepositories",
    "JobInRepositoriesTypedDict",
    "JobInTypedDict",
    "JobMetadataOut",
    "JobMetadataOutTypedDict",
    "JobOut",
    "JobOutTypedDict",
    "JobsAPIRoutesBatchCancelBatchJobRequest",
    "JobsAPIRoutesBatchCancelBatchJobRequestTypedDict",
    "JobsAPIRoutesBatchGetBatchJobRequest",
    "JobsAPIRoutesBatchGetBatchJobRequestTypedDict",
    "JobsAPIRoutesBatchGetBatchJobsRequest",
    "JobsAPIRoutesBatchGetBatchJobsRequestTypedDict",
    "JobsAPIRoutesFineTuningArchiveFineTunedModelRequest",
    "JobsAPIRoutesFineTuningArchiveFineTunedModelRequestTypedDict",
    "JobsAPIRoutesFineTuningCancelFineTuningJobRequest",
    "JobsAPIRoutesFineTuningCancelFineTuningJobRequestTypedDict",
    "JobsAPIRoutesFineTuningCreateFineTuningJobResponse",
    "JobsAPIRoutesFineTuningCreateFineTuningJobResponseTypedDict",
    "JobsAPIRoutesFineTuningGetFineTuningJobRequest",
    "JobsAPIRoutesFineTuningGetFineTuningJobRequestTypedDict",
    "JobsAPIRoutesFineTuningGetFineTuningJobsRequest",
    "JobsAPIRoutesFineTuningGetFineTuningJobsRequestTypedDict",
    "JobsAPIRoutesFineTuningStartFineTuningJobRequest",
    "JobsAPIRoutesFineTuningStartFineTuningJobRequestTypedDict",
    "JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequest",
    "JobsAPIRoutesFineTuningUnarchiveFineTunedModelRequestTypedDict",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelRequest",
    "JobsAPIRoutesFineTuningUpdateFineTunedModelRequestTypedDict",
    "JobsOut",
    "JobsOutObject",
    "JobsOutTypedDict",
    "LegacyJobMetadataOut",
    "LegacyJobMetadataOutObject",
    "LegacyJobMetadataOutTypedDict",
    "ListFilesOut",
    "ListFilesOutTypedDict",
    "Loc",
    "LocTypedDict",
    "Messages",
    "MessagesTypedDict",
    "MetricOut",
    "MetricOutTypedDict",
    "ModelCapabilities",
    "ModelCapabilitiesTypedDict",
    "ModelList",
    "ModelListTypedDict",
    "Object",
    "One",
    "OneTypedDict",
    "QueryParamStatus",
    "Repositories",
    "RepositoriesTypedDict",
    "ResponseFormat",
    "ResponseFormatTypedDict",
    "ResponseFormats",
    "RetrieveFileOut",
    "RetrieveFileOutTypedDict",
    "RetrieveModelV1ModelsModelIDGetRequest",
    "RetrieveModelV1ModelsModelIDGetRequestTypedDict",
    "RetrieveModelV1ModelsModelIDGetResponseRetrieveModelV1ModelsModelIDGet",
    "RetrieveModelV1ModelsModelIDGetResponseRetrieveModelV1ModelsModelIDGetTypedDict",
    "Role",
    "SDKError",
    "SampleType",
    "Security",
    "SecurityTypedDict",
    "Source",
    "Status",
    "Stop",
    "StopTypedDict",
    "SystemMessage",
    "SystemMessageContent",
    "SystemMessageContentTypedDict",
    "SystemMessageTypedDict",
    "TextChunk",
    "TextChunkType",
    "TextChunkTypedDict",
    "Tool",
    "ToolCall",
    "ToolCallTypedDict",
    "ToolChoice",
    "ToolChoiceEnum",
    "ToolChoiceTypedDict",
    "ToolMessage",
    "ToolMessageRole",
    "ToolMessageTypedDict",
    "ToolTypedDict",
    "ToolTypes",
    "TrainingFile",
    "TrainingFileTypedDict",
    "TrainingParameters",
    "TrainingParametersIn",
    "TrainingParametersInTypedDict",
    "TrainingParametersTypedDict",
    "Two",
    "TwoTypedDict",
    "Type",
    "UnarchiveFTModelOut",
    "UnarchiveFTModelOutObject",
    "UnarchiveFTModelOutTypedDict",
    "UpdateFTModelIn",
    "UpdateFTModelInTypedDict",
    "UploadFileOut",
    "UploadFileOutTypedDict",
    "UsageInfo",
    "UsageInfoTypedDict",
    "UserMessage",
    "UserMessageContent",
    "UserMessageContentTypedDict",
    "UserMessageRole",
    "UserMessageTypedDict",
    "ValidationError",
    "ValidationErrorTypedDict",
    "WandbIntegration",
    "WandbIntegrationOut",
    "WandbIntegrationOutType",
    "WandbIntegrationOutTypedDict",
    "WandbIntegrationType",
    "WandbIntegrationTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .deltamessage import DeltaMessage, DeltaMessageTypedDict
from mistralai.types import BaseModel, Nullable, UNSET_SENTINEL, UnrecognizedStr
from mistralai.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Literal, Union
from typing_extensions import Annotated, TypedDict


CompletionResponseStreamChoiceFinishReason = Union[
    Literal["stop", "length", "error", "tool_calls"], UnrecognizedStr
]


class CompletionResponseStreamChoiceTypedDict(TypedDict):
    index: int
    delta: DeltaMessageTypedDict
    finish_reason: Nullable[CompletionResponseStreamChoiceFinishReason]


class CompletionResponseStreamChoice(BaseModel):
    index: int

    delta: DeltaMessage

    finish_reason: Annotated[
        Nullable[CompletionResponseStreamChoiceFinishReason],
        PlainValidator(validate_open_enum(False)),
    ]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["finish_reason"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai_gcp.types import BaseModel
from mistralai_gcp.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, TypedDict


Type = Literal["text"]


class TextChunkTypedDict(TypedDict):
    text: str
    type: Type


class TextChunk(BaseModel):
    text: str

    TYPE: Annotated[
        Annotated[Optional[Type], AfterValidator(validate_const("text"))],
        pydantic.Field(alias="type"),
    ] = "text"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .basemodelcard import BaseModelCard, BaseModelCardTypedDict
from .ftmodelcard import FTModelCard, FTModelCardTypedDict
from mistralai.types import BaseModel
from mistralai.utils import FieldMetadata, PathParamMetadata, get_discriminator
from pydantic import Discriminator, Tag
from typing import Union
from typing_extensions import Annotated, TypedDict


class RetrieveModelV1ModelsModelIDGetRequestTypedDict(TypedDict):
    model_id: str
    r"""The ID of the model to retrieve."""


class RetrieveModelV1ModelsModelIDGetRequest(BaseModel):
    model_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The ID of the model to retrieve."""


RetrieveModelV1ModelsModelIDGetResponseRetrieveModelV1ModelsModelIDGetTypedDict = Union[
    BaseModelCardTypedDict, FTModelCardTypedDict
]
r"""Successful Response"""


RetrieveModelV1ModelsModelIDGetResponseRetrieveModelV1ModelsModelIDGet = Annotated[
    Union[
        Annotated[BaseModelCard, Tag("base")], Annotated[FTModelCard, Tag("fine-tuned")]
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]
r"""Successful Response"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .function import Function, FunctionTypedDict
from .tooltypes import ToolTypes
from mistralai_gcp.types import BaseModel
from mistralai_gcp.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ToolTypedDict(TypedDict):
    function: FunctionTypedDict
    type: NotRequired[ToolTypes]


class Tool(BaseModel):
    function: Function

    type: Annotated[Optional[ToolTypes], PlainValidator(validate_open_enum(False))] = (
        None
    )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai_gcp.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional, Union
from typing_extensions import NotRequired, TypedDict


FIMCompletionRequestStopTypedDict = Union[str, List[str]]
r"""Stop generation if this token is detected. Or if one of these tokens is detected when providing an array"""


FIMCompletionRequestStop = Union[str, List[str]]
r"""Stop generation if this token is detected. Or if one of these tokens is detected when providing an array"""


class FIMCompletionRequestTypedDict(TypedDict):
    model: Nullable[str]
    r"""ID of the model to use. Only compatible for now with:
    - `codestral-2405`
    - `codestral-latest`
    """
    prompt: str
    r"""The text/code to complete."""
    temperature: NotRequired[Nullable[float]]
    r"""What sampling temperature to use, we recommend between 0.0 and 0.7. Higher values like 0.7 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. We generally recommend altering this or `top_p` but not both. The default value varies depending on the model you are targeting. Call the `/models` endpoint to retrieve the appropriate value."""
    top_p: NotRequired[float]
    r"""Nucleus sampling, where the model considers the results of the tokens with `top_p` probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered. We generally recommend altering this or `temperature` but not both."""
    max_tokens: NotRequired[Nullable[int]]
    r"""The maximum number of tokens to generate in the completion. The token count of your prompt plus `max_tokens` cannot exceed the model's context length."""
    stream: NotRequired[bool]
    r"""Whether to stream back partial progress. If set, tokens will be sent as data-only server-side events as they become available, with the stream terminated by a data: [DONE] message. Otherwise, the server will hold the request open until the timeout or until completion, with the response containing the full result as JSON."""
    stop: NotRequired[FIMCompletionRequestStopTypedDict]
    r"""Stop generation if this token is detected. Or if one of these tokens is detected when providing an array"""
    random_seed: NotRequired[Nullable[int]]
    r"""The seed to use for random sampling. If set, different calls will generate deterministic results."""
    suffix: NotRequired[Nullable[str]]
    r"""Optional text/code that adds more context for the model. When given a `prompt` and a `suffix` the model will fill what is between them. When `suffix` is not provided, the model will simply execute completion starting with `prompt`."""
    min_tokens: NotRequired[Nullable[int]]
    r"""The minimum number of tokens to generate in the completion."""


class FIMCompletionRequest(BaseModel):
    model: Nullable[str]
    r"""ID of the model to use. Only compatible for now with:
    - `codestral-2405`
    - `codestral-latest`
    """

    prompt: str
    r"""The text/code to complete."""

    temperature: OptionalNullable[float] = UNSET
    r"""What sampling temperature to use, we recommend between 0.0 and 0.7. Higher values like 0.7 will make the output more random, while lower values like 0.2 will make it more focused and deterministic. We generally recommend altering this or `top_p` but not both. The default value varies depending on the model you are targeting. Call the `/models` endpoint to retrieve the appropriate value."""

    top_p: Optional[float] = 1
    r"""Nucleus sampling, where the model considers the results of the tokens with `top_p` probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered. We generally recommend altering this or `temperature` but not both."""

    max_tokens: OptionalNullable[int] = UNSET
    r"""The maximum number of tokens to generate in the completion. The token count of your prompt plus `max_tokens` cannot exceed the model's context length."""

    stream: Optional[bool] = False
    r"""Whether to stream back partial progress. If set, tokens will be sent as data-only server-side events as they become available, with the stream terminated by a data: [DONE] message. Otherwise, the server will hold the request open until the timeout or until completion, with the response containing the full result as JSON."""

    stop: Optional[FIMCompletionRequestStop] = None
    r"""Stop generation if this token is detected. Or if one of these tokens is detected when providing an array"""

    random_seed: OptionalNullable[int] = UNSET
    r"""The seed to use for random sampling. If set, different calls will generate deterministic results."""

    suffix: OptionalNullable[str] = UNSET
    r"""Optional text/code that adds more context for the model. When given a `prompt` and a `suffix` the model will fill what is between them. When `suffix` is not provided, the model will simply execute completion starting with `prompt`."""

    min_tokens: OptionalNullable[int] = UNSET
    r"""The minimum number of tokens to generate in the completion."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "temperature",
            "top_p",
            "max_tokens",
            "stream",
            "stop",
            "random_seed",
            "suffix",
            "min_tokens",
        ]
        nullable_fields = [
            "model",
            "temperature",
            "max_tokens",
            "random_seed",
            "suffix",
            "min_tokens",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import re
import json
from typing import Callable, TypeVar, Optional, Generator, AsyncGenerator, Tuple
import httpx

T = TypeVar("T")


class ServerEvent:
    id: Optional[str] = None
    event: Optional[str] = None
    data: Optional[str] = None
    retry: Optional[int] = None


MESSAGE_BOUNDARIES = [
    b"\r\n\r\n",
    b"\n\n",
    b"\r\r",
]


async def stream_events_async(
    response: httpx.Response,
    decoder: Callable[[str], T],
    sentinel: Optional[str] = None,
) -> AsyncGenerator[T, None]:
    buffer = bytearray()
    position = 0
    discard = False
    async for chunk in response.aiter_bytes():
        # We've encountered the sentinel value and should no longer process
        # incoming data. Instead we throw new data away until the server closes
        # the connection.
        if discard:
            continue

        buffer += chunk
        for i in range(position, len(buffer)):
            char = buffer[i : i + 1]
            seq: Optional[bytes] = None
            if char in [b"\r", b"\n"]:
                for boundary in MESSAGE_BOUNDARIES:
                    seq = _peek_sequence(i, buffer, boundary)
                    if seq is not None:
                        break
            if seq is None:
                continue

            block = buffer[position:i]
            position = i + len(seq)
            event, discard = _parse_event(block, decoder, sentinel)
            if event is not None:
                yield event

        if position > 0:
            buffer = buffer[position:]
            position = 0

    event, discard = _parse_event(buffer, decoder, sentinel)
    if event is not None:
        yield event


def stream_events(
    response: httpx.Response,
    decoder: Callable[[str], T],
    sentinel: Optional[str] = None,
) -> Generator[T, None, None]:
    buffer = bytearray()
    position = 0
    discard = False
    for chunk in response.iter_bytes():
        # We've encountered the sentinel value and should no longer process
        # incoming data. Instead we throw new data away until the server closes
        # the connection.
        if discard:
            continue

        buffer += chunk
        for i in range(position, len(buffer)):
            char = buffer[i : i + 1]
            seq: Optional[bytes] = None
            if char in [b"\r", b"\n"]:
                for boundary in MESSAGE_BOUNDARIES:
                    seq = _peek_sequence(i, buffer, boundary)
                    if seq is not None:
                        break
            if seq is None:
                continue

            block = buffer[position:i]
            position = i + len(seq)
            event, discard = _parse_event(block, decoder, sentinel)
            if event is not None:
                yield event

        if position > 0:
            buffer = buffer[position:]
            position = 0

    event, discard = _parse_event(buffer, decoder, sentinel)
    if event is not None:
        yield event


def _parse_event(
    raw: bytearray, decoder: Callable[[str], T], sentinel: Optional[str] = None
) -> Tuple[Optional[T], bool]:
    block = raw.decode()
    lines = re.split(r"\r?\n|\r", block)
    publish = False
    event = ServerEvent()
    data = ""
    for line in lines:
        if not line:
            continue

        delim = line.find(":")
        if delim <= 0:
            continue

        field = line[0:delim]
        value = line[delim + 1 :] if delim < len(line) - 1 else ""
        if len(value) and value[0] == " ":
            value = value[1:]

        if field == "event":
            event.event = value
            publish = True
        elif field == "data":
            data += value + "\n"
            publish = True
        elif field == "id":
            event.id = value
            publish = True
        elif field == "retry":
            event.retry = int(value) if value.isdigit() else None
            publish = True

    if sentinel and data == f"{sentinel}\n":
        return None, True

    if data:
        data = data[:-1]
        event.data = data

        data_is_primitive = (
            data.isnumeric() or data == "true" or data == "false" or data == "null"
        )
        data_is_json = (
            data.startswith("{") or data.startswith("[") or data.startswith('"')
        )

        if data_is_primitive or data_is_json:
            try:
                event.data = json.loads(data)
            except Exception:
                pass

    out = None
    if publish:
        out = decoder(json.dumps(event.__dict__))

    return out, False


def _peek_sequence(position: int, buffer: bytearray, sequence: bytes):
    if len(sequence) > (len(buffer) - position):
        return None

    for i, seq in enumerate(sequence):
        if buffer[position + i] != seq:
            return None

    return sequence



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class BatchErrorTypedDict(TypedDict):
    message: str
    count: NotRequired[int]


class BatchError(BaseModel):
    message: str

    count: Optional[int] = 1



from typing import Optional

from .client import MIGRATION_MESSAGE


class MistralAsyncClient:
    def __init__(
        self,
        api_key: Optional[str] = None,
        endpoint: str = "",
        max_retries: int = 5,
        timeout: int = 120,
        max_concurrent_requests: int = 64,
    ):
        raise NotImplementedError(MIGRATION_MESSAGE)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class FunctionTypedDict(TypedDict):
    name: str
    parameters: Dict[str, Any]
    description: NotRequired[str]


class Function(BaseModel):
    name: str

    parameters: Dict[str, Any]

    description: Optional[str] = ""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
import httpx
from mistralai import models, utils
from mistralai._hooks import HookContext
from mistralai.types import OptionalNullable, UNSET
from mistralai.utils import get_security_from_env
from typing import List, Optional, Union


class Files(BaseSDK):
    r"""Files API"""

    def upload(
        self,
        *,
        file: Union[models.File, models.FileTypedDict],
        purpose: Optional[models.FilePurpose] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.UploadFileOut]:
        r"""Upload File

        Upload a file that can be used across various endpoints.

        The size of individual files can be a maximum of 512 MB. The Fine-tuning API only supports .jsonl files.

        Please contact us if you need to increase these storage limits.

        :param file: The File object (not file name) to be uploaded.  To upload a file and specify a custom file name you should format your request as such:  ```bash  file=@path/to/your/file.jsonl;filename=custom_name.jsonl  ```  Otherwise, you can just keep the original file name:  ```bash  file=@path/to/your/file.jsonl  ```
        :param purpose:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesUploadFileMultiPartBodyParams(
            file=utils.get_pydantic_model(file, models.File),
            purpose=purpose,
        )

        req = self.build_request(
            method="POST",
            path="/v1/files",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "multipart",
                models.FilesAPIRoutesUploadFileMultiPartBodyParams,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="files_api_routes_upload_file",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.UploadFileOut])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def upload_async(
        self,
        *,
        file: Union[models.File, models.FileTypedDict],
        purpose: Optional[models.FilePurpose] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.UploadFileOut]:
        r"""Upload File

        Upload a file that can be used across various endpoints.

        The size of individual files can be a maximum of 512 MB. The Fine-tuning API only supports .jsonl files.

        Please contact us if you need to increase these storage limits.

        :param file: The File object (not file name) to be uploaded.  To upload a file and specify a custom file name you should format your request as such:  ```bash  file=@path/to/your/file.jsonl;filename=custom_name.jsonl  ```  Otherwise, you can just keep the original file name:  ```bash  file=@path/to/your/file.jsonl  ```
        :param purpose:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesUploadFileMultiPartBodyParams(
            file=utils.get_pydantic_model(file, models.File),
            purpose=purpose,
        )

        req = self.build_request_async(
            method="POST",
            path="/v1/files",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request,
                False,
                False,
                "multipart",
                models.FilesAPIRoutesUploadFileMultiPartBodyParams,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="files_api_routes_upload_file",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.UploadFileOut])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def list(
        self,
        *,
        page: Optional[int] = 0,
        page_size: Optional[int] = 100,
        sample_type: OptionalNullable[List[models.SampleType]] = UNSET,
        source: OptionalNullable[List[models.Source]] = UNSET,
        search: OptionalNullable[str] = UNSET,
        purpose: OptionalNullable[models.FilePurpose] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.ListFilesOut]:
        r"""List Files

        Returns a list of files that belong to the user's organization.

        :param page:
        :param page_size:
        :param sample_type:
        :param source:
        :param search:
        :param purpose:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesListFilesRequest(
            page=page,
            page_size=page_size,
            sample_type=sample_type,
            source=source,
            search=search,
            purpose=purpose,
        )

        req = self.build_request(
            method="GET",
            path="/v1/files",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="files_api_routes_list_files",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.ListFilesOut])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def list_async(
        self,
        *,
        page: Optional[int] = 0,
        page_size: Optional[int] = 100,
        sample_type: OptionalNullable[List[models.SampleType]] = UNSET,
        source: OptionalNullable[List[models.Source]] = UNSET,
        search: OptionalNullable[str] = UNSET,
        purpose: OptionalNullable[models.FilePurpose] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.ListFilesOut]:
        r"""List Files

        Returns a list of files that belong to the user's organization.

        :param page:
        :param page_size:
        :param sample_type:
        :param source:
        :param search:
        :param purpose:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesListFilesRequest(
            page=page,
            page_size=page_size,
            sample_type=sample_type,
            source=source,
            search=search,
            purpose=purpose,
        )

        req = self.build_request_async(
            method="GET",
            path="/v1/files",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="files_api_routes_list_files",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.ListFilesOut])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def retrieve(
        self,
        *,
        file_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.RetrieveFileOut]:
        r"""Retrieve File

        Returns information about a specific file.

        :param file_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesRetrieveFileRequest(
            file_id=file_id,
        )

        req = self.build_request(
            method="GET",
            path="/v1/files/{file_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="files_api_routes_retrieve_file",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.RetrieveFileOut])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def retrieve_async(
        self,
        *,
        file_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.RetrieveFileOut]:
        r"""Retrieve File

        Returns information about a specific file.

        :param file_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesRetrieveFileRequest(
            file_id=file_id,
        )

        req = self.build_request_async(
            method="GET",
            path="/v1/files/{file_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="files_api_routes_retrieve_file",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.RetrieveFileOut])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def delete(
        self,
        *,
        file_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.DeleteFileOut]:
        r"""Delete File

        Delete a file.

        :param file_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesDeleteFileRequest(
            file_id=file_id,
        )

        req = self.build_request(
            method="DELETE",
            path="/v1/files/{file_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="files_api_routes_delete_file",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.DeleteFileOut])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def delete_async(
        self,
        *,
        file_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[models.DeleteFileOut]:
        r"""Delete File

        Delete a file.

        :param file_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesDeleteFileRequest(
            file_id=file_id,
        )

        req = self.build_request_async(
            method="DELETE",
            path="/v1/files/{file_id}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="files_api_routes_delete_file",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json(http_res.text, Optional[models.DeleteFileOut])
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    def download(
        self,
        *,
        file_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[httpx.Response]:
        r"""Download File

        Download a file

        :param file_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesDownloadFileRequest(
            file_id=file_id,
        )

        req = self.build_request(
            method="GET",
            path="/v1/files/{file_id}/content",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/octet-stream",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                operation_id="files_api_routes_download_file",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/octet-stream"):
            return http_res
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = utils.stream_to_text(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )

    async def download_async(
        self,
        *,
        file_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
    ) -> Optional[httpx.Response]:
        r"""Download File

        Download a file

        :param file_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url

        request = models.FilesAPIRoutesDownloadFileRequest(
            file_id=file_id,
        )

        req = self.build_request_async(
            method="GET",
            path="/v1/files/{file_id}/content",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/octet-stream",
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                operation_id="files_api_routes_download_file",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["4XX", "5XX"],
            stream=True,
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/octet-stream"):
            return http_res
        if utils.match_response(http_res, ["4XX", "5XX"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.SDKError(
                "API error occurred", http_res.status_code, http_res_text, http_res
            )

        content_type = http_res.headers.get("Content-Type")
        http_res_text = await utils.stream_to_text_async(http_res)
        raise models.SDKError(
            f"Unexpected response received (code: {http_res.status_code}, type: {content_type})",
            http_res.status_code,
            http_res_text,
            http_res,
        )



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ModelCapabilitiesTypedDict(TypedDict):
    completion_chat: NotRequired[bool]
    completion_fim: NotRequired[bool]
    function_calling: NotRequired[bool]
    fine_tuning: NotRequired[bool]
    vision: NotRequired[bool]


class ModelCapabilities(BaseModel):
    completion_chat: Optional[bool] = True

    completion_fim: Optional[bool] = False

    function_calling: Optional[bool] = True

    fine_tuning: Optional[bool] = False

    vision: Optional[bool] = False



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from mistralai.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


ArchiveFTModelOutObject = Literal["model"]


class ArchiveFTModelOutTypedDict(TypedDict):
    id: str
    object: ArchiveFTModelOutObject
    archived: NotRequired[bool]


class ArchiveFTModelOut(BaseModel):
    id: str

    OBJECT: Annotated[
        Annotated[
            Optional[ArchiveFTModelOutObject], AfterValidator(validate_const("model"))
        ],
        pydantic.Field(alias="object"),
    ] = "model"

    archived: Optional[bool] = True



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from mistralai.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


LegacyJobMetadataOutObject = Literal["job.metadata"]


class LegacyJobMetadataOutTypedDict(TypedDict):
    details: str
    expected_duration_seconds: NotRequired[Nullable[int]]
    r"""The approximated time (in seconds) for the fine-tuning process to complete."""
    cost: NotRequired[Nullable[float]]
    r"""The cost of the fine-tuning job."""
    cost_currency: NotRequired[Nullable[str]]
    r"""The currency used for the fine-tuning job cost."""
    train_tokens_per_step: NotRequired[Nullable[int]]
    r"""The number of tokens consumed by one training step."""
    train_tokens: NotRequired[Nullable[int]]
    r"""The total number of tokens used during the fine-tuning process."""
    data_tokens: NotRequired[Nullable[int]]
    r"""The total number of tokens in the training dataset."""
    estimated_start_time: NotRequired[Nullable[int]]
    deprecated: NotRequired[bool]
    epochs: NotRequired[Nullable[float]]
    r"""The number of complete passes through the entire training dataset."""
    training_steps: NotRequired[Nullable[int]]
    r"""The number of training steps to perform. A training step refers to a single update of the model weights during the fine-tuning process. This update is typically calculated using a batch of samples from the training dataset."""
    object: LegacyJobMetadataOutObject


class LegacyJobMetadataOut(BaseModel):
    details: str

    expected_duration_seconds: OptionalNullable[int] = UNSET
    r"""The approximated time (in seconds) for the fine-tuning process to complete."""

    cost: OptionalNullable[float] = UNSET
    r"""The cost of the fine-tuning job."""

    cost_currency: OptionalNullable[str] = UNSET
    r"""The currency used for the fine-tuning job cost."""

    train_tokens_per_step: OptionalNullable[int] = UNSET
    r"""The number of tokens consumed by one training step."""

    train_tokens: OptionalNullable[int] = UNSET
    r"""The total number of tokens used during the fine-tuning process."""

    data_tokens: OptionalNullable[int] = UNSET
    r"""The total number of tokens in the training dataset."""

    estimated_start_time: OptionalNullable[int] = UNSET

    deprecated: Optional[bool] = True

    epochs: OptionalNullable[float] = UNSET
    r"""The number of complete passes through the entire training dataset."""

    training_steps: OptionalNullable[int] = UNSET
    r"""The number of training steps to perform. A training step refers to a single update of the model weights during the fine-tuning process. This update is typically calculated using a batch of samples from the training dataset."""

    OBJECT: Annotated[
        Annotated[
            Optional[LegacyJobMetadataOutObject],
            AfterValidator(validate_const("job.metadata")),
        ],
        pydantic.Field(alias="object"),
    ] = "job.metadata"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "expected_duration_seconds",
            "cost",
            "cost_currency",
            "train_tokens_per_step",
            "train_tokens",
            "data_tokens",
            "estimated_start_time",
            "deprecated",
            "epochs",
            "training_steps",
            "object",
        ]
        nullable_fields = [
            "expected_duration_seconds",
            "cost",
            "cost_currency",
            "train_tokens_per_step",
            "train_tokens",
            "data_tokens",
            "estimated_start_time",
            "epochs",
            "training_steps",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .finetuneablemodel import FineTuneableModel
from .githubrepositoryout import GithubRepositoryOut, GithubRepositoryOutTypedDict
from .jobmetadataout import JobMetadataOut, JobMetadataOutTypedDict
from .trainingparameters import TrainingParameters, TrainingParametersTypedDict
from .wandbintegrationout import WandbIntegrationOut, WandbIntegrationOutTypedDict
from mistralai.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from mistralai.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


Status = Literal[
    "QUEUED",
    "STARTED",
    "VALIDATING",
    "VALIDATED",
    "RUNNING",
    "FAILED_VALIDATION",
    "FAILED",
    "SUCCESS",
    "CANCELLED",
    "CANCELLATION_REQUESTED",
]
r"""The current status of the fine-tuning job."""

Object = Literal["job"]
r"""The object type of the fine-tuning job."""

IntegrationsTypedDict = WandbIntegrationOutTypedDict


Integrations = WandbIntegrationOut


RepositoriesTypedDict = GithubRepositoryOutTypedDict


Repositories = GithubRepositoryOut


class JobOutTypedDict(TypedDict):
    id: str
    r"""The ID of the job."""
    auto_start: bool
    hyperparameters: TrainingParametersTypedDict
    model: FineTuneableModel
    r"""The name of the model to fine-tune."""
    status: Status
    r"""The current status of the fine-tuning job."""
    job_type: str
    r"""The type of job (`FT` for fine-tuning)."""
    created_at: int
    r"""The UNIX timestamp (in seconds) for when the fine-tuning job was created."""
    modified_at: int
    r"""The UNIX timestamp (in seconds) for when the fine-tuning job was last modified."""
    training_files: List[str]
    r"""A list containing the IDs of uploaded files that contain training data."""
    validation_files: NotRequired[Nullable[List[str]]]
    r"""A list containing the IDs of uploaded files that contain validation data."""
    object: Object
    r"""The object type of the fine-tuning job."""
    fine_tuned_model: NotRequired[Nullable[str]]
    r"""The name of the fine-tuned model that is being created. The value will be `null` if the fine-tuning job is still running."""
    suffix: NotRequired[Nullable[str]]
    r"""Optional text/code that adds more context for the model. When given a `prompt` and a `suffix` the model will fill what is between them. When `suffix` is not provided, the model will simply execute completion starting with `prompt`."""
    integrations: NotRequired[Nullable[List[IntegrationsTypedDict]]]
    r"""A list of integrations enabled for your fine-tuning job."""
    trained_tokens: NotRequired[Nullable[int]]
    r"""Total number of tokens trained."""
    repositories: NotRequired[List[RepositoriesTypedDict]]
    metadata: NotRequired[Nullable[JobMetadataOutTypedDict]]


class JobOut(BaseModel):
    id: str
    r"""The ID of the job."""

    auto_start: bool

    hyperparameters: TrainingParameters

    model: FineTuneableModel
    r"""The name of the model to fine-tune."""

    status: Status
    r"""The current status of the fine-tuning job."""

    job_type: str
    r"""The type of job (`FT` for fine-tuning)."""

    created_at: int
    r"""The UNIX timestamp (in seconds) for when the fine-tuning job was created."""

    modified_at: int
    r"""The UNIX timestamp (in seconds) for when the fine-tuning job was last modified."""

    training_files: List[str]
    r"""A list containing the IDs of uploaded files that contain training data."""

    validation_files: OptionalNullable[List[str]] = UNSET
    r"""A list containing the IDs of uploaded files that contain validation data."""

    OBJECT: Annotated[
        Annotated[Optional[Object], AfterValidator(validate_const("job"))],
        pydantic.Field(alias="object"),
    ] = "job"
    r"""The object type of the fine-tuning job."""

    fine_tuned_model: OptionalNullable[str] = UNSET
    r"""The name of the fine-tuned model that is being created. The value will be `null` if the fine-tuning job is still running."""

    suffix: OptionalNullable[str] = UNSET
    r"""Optional text/code that adds more context for the model. When given a `prompt` and a `suffix` the model will fill what is between them. When `suffix` is not provided, the model will simply execute completion starting with `prompt`."""

    integrations: OptionalNullable[List[Integrations]] = UNSET
    r"""A list of integrations enabled for your fine-tuning job."""

    trained_tokens: OptionalNullable[int] = UNSET
    r"""Total number of tokens trained."""

    repositories: Optional[List[Repositories]] = None

    metadata: OptionalNullable[JobMetadataOut] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "validation_files",
            "object",
            "fine_tuned_model",
            "suffix",
            "integrations",
            "trained_tokens",
            "repositories",
            "metadata",
        ]
        nullable_fields = [
            "validation_files",
            "fine_tuned_model",
            "suffix",
            "integrations",
            "trained_tokens",
            "metadata",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "mistralai-gcp"
__version__: str = "1.2.0"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .jobout import JobOut, JobOutTypedDict
from mistralai.types import BaseModel
from mistralai.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


JobsOutObject = Literal["list"]


class JobsOutTypedDict(TypedDict):
    total: int
    data: NotRequired[List[JobOutTypedDict]]
    object: JobsOutObject


class JobsOut(BaseModel):
    total: int

    data: Optional[List[JobOut]] = None

    OBJECT: Annotated[
        Annotated[Optional[JobsOutObject], AfterValidator(validate_const("list"))],
        pydantic.Field(alias="object"),
    ] = "list"



# THIS FILE IS THE EXACT COPY OF THE ORIGINAL FILE FROM src/mistralai/_hooks/custom_user_agent.py
from typing import Union

import httpx

from .types import BeforeRequestContext, BeforeRequestHook


class CustomUserAgentHook(BeforeRequestHook):
    def before_request(
        self, hook_ctx: BeforeRequestContext, request: httpx.Request
    ) -> Union[httpx.Request, Exception]:
        request.headers["user-agent"] = (
            "mistral-client-python/" + request.headers["user-agent"].split(" ")[1]
        )
        return request



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import BaseModel
from typing import Any, Dict, Union
from typing_extensions import TypedDict


ArgumentsTypedDict = Union[Dict[str, Any], str]


Arguments = Union[Dict[str, Any], str]


class FunctionCallTypedDict(TypedDict):
    name: str
    arguments: ArgumentsTypedDict


class FunctionCall(BaseModel):
    name: str

    arguments: Arguments



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mistralai.types import UnrecognizedStr
from typing import Literal, Union


ToolTypes = Union[Literal["function"], UnrecognizedStr]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .metricout import MetricOut, MetricOutTypedDict
from mistralai.types import BaseModel
from typing_extensions import TypedDict


class CheckpointOutTypedDict(TypedDict):
    metrics: MetricOutTypedDict
    r"""Metrics at the step number during the fine-tuning job. Use these metrics to assess if the training is going smoothly (loss should decrease, token accuracy should increase)."""
    step_number: int
    r"""The step number that the checkpoint was created at."""
    created_at: int
    r"""The UNIX timestamp (in seconds) for when the checkpoint was created."""


class CheckpointOut(BaseModel):
    metrics: MetricOut
    r"""Metrics at the step number during the fine-tuning job. Use these metrics to assess if the training is going smoothly (loss should decrease, token accuracy should increase)."""

    step_number: int
    r"""The step number that the checkpoint was created at."""

    created_at: int
    r"""The UNIX timestamp (in seconds) for when the checkpoint was created."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from mistralai.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from mistralai.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


QueryParamStatus = Literal[
    "QUEUED",
    "STARTED",
    "VALIDATING",
    "VALIDATED",
    "RUNNING",
    "FAILED_VALIDATION",
    "FAILED",
    "SUCCESS",
    "CANCELLED",
    "CANCELLATION_REQUESTED",
]
r"""The current job state to filter on. When set, the other results are not displayed."""


class JobsAPIRoutesFineTuningGetFineTuningJobsRequestTypedDict(TypedDict):
    page: NotRequired[int]
    r"""The page number of the results to be returned."""
    page_size: NotRequired[int]
    r"""The number of items to return per page."""
    model: NotRequired[Nullable[str]]
    r"""The model name used for fine-tuning to filter on. When set, the other results are not displayed."""
    created_after: NotRequired[Nullable[datetime]]
    r"""The date/time to filter on. When set, the results for previous creation times are not displayed."""
    created_by_me: NotRequired[bool]
    r"""When set, only return results for jobs created by the API caller. Other results are not displayed."""
    status: NotRequired[Nullable[QueryParamStatus]]
    r"""The current job state to filter on. When set, the other results are not displayed."""
    wandb_project: NotRequired[Nullable[str]]
    r"""The Weights and Biases project to filter on. When set, the other results are not displayed."""
    wandb_name: NotRequired[Nullable[str]]
    r"""The Weight and Biases run name to filter on. When set, the other results are not displayed."""
    suffix: NotRequired[Nullable[str]]
    r"""The model suffix to filter on. When set, the other results are not displayed."""


class JobsAPIRoutesFineTuningGetFineTuningJobsRequest(BaseModel):
    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 0
    r"""The page number of the results to be returned."""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
    r"""The number of items to return per page."""

    model: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""The model name used for fine-tuning to filter on. When set, the other results are not displayed."""

    created_after: Annotated[
        OptionalNullable[datetime],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""The date/time to filter on. When set, the results for previous creation times are not displayed."""

    created_by_me: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = False
    r"""When set, only return results for jobs created by the API caller. Other results are not displayed."""

    status: Annotated[
        OptionalNullable[QueryParamStatus],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""The current job state to filter on. When set, the other results are not displayed."""

    wandb_project: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""The Weights and Biases project to filter on. When set, the other results are not displayed."""

    wandb_name: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""The Weight and Biases run name to filter on. When set, the other results are not displayed."""

    suffix: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""The model suffix to filter on. When set, the other results are not displayed."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "page",
            "page_size",
            "model",
            "created_after",
            "created_by_me",
            "status",
            "wandb_project",
            "wandb_name",
            "suffix",
        ]
        nullable_fields = [
            "model",
            "created_after",
            "status",
            "wandb_project",
            "wandb_name",
            "suffix",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
